@@ -22,6 +22,7 @@
 #include "qa_dotprod.h"
 #include "qa_float_dotprod_x86.h"
 #include "qa_complex_dotprod_x86.h"
+#include "qa_ccomplex_dotprod_x86.h"
 
 CppUnit::TestSuite *
 qa_dotprod_suite ()
@@ -30,6 +31,7 @@ qa_dotprod_suite ()
 
   s->addTest (qa_float_dotprod_x86::suite ());
   s->addTest (qa_complex_dotprod_x86::suite ());
+  s->addTest (qa_ccomplex_dotprod_x86::suite ());
 
   return s;
 }
