@@ -788,11 +788,11 @@ punt (const std::string msg)
   throw std::runtime_error (msg);
 }
 
-gr_vector_double
+std::vector<double>
 gr_remez (int order,
-	  const gr_vector_double &arg_bands,
-	  const gr_vector_double &arg_response,
-	  const gr_vector_double &arg_weight,
+	  const std::vector<double> &arg_bands,
+	  const std::vector<double> &arg_response,
+	  const std::vector<double> &arg_weight,
 	  const std::string filter_type,
 	  int grid_density
 	  ) throw (std::runtime_error)
@@ -861,7 +861,7 @@ gr_remez (int order,
   if (err == -3)
     punt ("gr_remez: too many extremals -- cannot continue");
 
-  return gr_vector_double (&coeff[0], &coeff[numtaps]);
+  return std::vector<double> (&coeff[0], &coeff[numtaps]);
 }
 
 
