@@ -55,6 +55,14 @@ class gr_file_source : public gr_sync_block
   int work (int noutput_items,
 	    gr_vector_const_void_star &input_items,
 	    gr_vector_void_star &output_items);
+
+  /*!
+   * \brief seek file to \p seek_point relative to \p whence
+   *
+   * \param seek_point	sample offset in file
+   * \param whence	one of SEEK_SET, SEEK_CUR, SEEK_END (man fseek)
+   */
+  bool gr_file_source::seek (long seek_point, int whence);
 };
 
 #endif /* INCLUDED_GR_FILE_SOURCE_H */
