@@ -39,7 +39,7 @@ void
 qa_gr_io_signature::t2 ()
 {
   gr_io_signature_sptr p =
-    gr_make_io_signature (3, gr_io_signature::INFINITE, sizeof (int));
+    gr_make_io_signature (3, gr_io_signature::IO_INFINITE, sizeof (int));
 
   CPPUNIT_ASSERT_EQUAL (p->min_streams (), 3);
   CPPUNIT_ASSERT_EQUAL (p->sizeof_stream_item (0), sizeof (int));
