@@ -207,6 +207,26 @@ class test_flow_graph (qa_basic_flow_graph.test_basic_flow_graph):
         dst_data = dst1.data ()
         self.assertEqual (expected_result, dst_data)
         
+    def test_112 (self):
+        fg = self.fg
+        nop1 = gr.nop (gr.sizeof_int)
+        nop2 = gr.nop (gr.sizeof_int)
+        nop3 = gr.nop (gr.sizeof_int)
+        fg.connect ((nop1, 0), (nop2, 0))
+        fg.connect ((nop1, 1), (nop3, 0))
+        fg._setup_connections ()
+        self.assertEqual (2, nop1.detail().noutputs())
+
+    def test_113 (self):
+        fg = self.fg
+        nop1 = gr.nop (gr.sizeof_int)
+        nop2 = gr.nop (gr.sizeof_int)
+        nop3 = gr.nop (gr.sizeof_int)
+        fg.connect ((nop1, 0), (nop2, 0))
+        fg.connect ((nop1, 0), (nop3, 0))
+        fg._setup_connections ()
+        self.assertEqual (1, nop1.detail().noutputs())
+
     def test_200_partition (self):
         self.leak_check (self.body_200)
 
