@@ -1,5 +1,5 @@
 #
-# Copyright 2004 Free Software Foundation, Inc.
+# Copyright 2004,2005 Free Software Foundation, Inc.
 # 
 # This file is part of GNU Radio
 # 
@@ -33,9 +33,39 @@ from gnuradio import gr
 remez = gr.remez
 
 # ----------------------------------------------------------------
-# The fundamental interface is remezord followed by remez
-#
-# Examples to come...
+
+def low_pass (Fs, freq1, freq2, passband_ripple_db, stopband_atten_db,
+              nextra_taps=0):
+    passband_dev = passband_ripple_to_dev (passband_ripple_db)
+    stopband_dev = stopband_atten_to_dev (stopband_atten_db)
+    desired_ampls = (1, 0)
+    (n, fo, ao, w) = remezord ([freq1, freq2], desired_ampls,
+                               [passband_dev, stopband_dev], Fs)
+    taps = gr.remez (n + nextra_taps, fo, ao, w, "bandpass")
+    return taps
+
+# FIXME high_passs is broken...
+def high_pass (Fs, freq1, freq2, stopband_atten_db, passband_ripple_db, 
+               nextra_taps=0):
+    """FIXME: broken"""
+    passband_dev = passband_ripple_to_dev (passband_ripple_db)
+    stopband_dev = stopband_atten_to_dev (stopband_atten_db)
+    desired_ampls = (0, 1)
+    (n, fo, ao, w) = remezord ([freq1, freq2], desired_ampls,
+                               [stopband_dev, passband_dev], Fs)
+    taps = gr.remez (n + nextra_taps, fo, ao, w, "bandpass")
+    return taps
+
+# ----------------------------------------------------------------
+
+def stopband_atten_to_dev (atten_db):
+    """Convert a stopband attenuation in dB to an absolute value"""
+    return 10**(-atten_db/20)
+
+def passband_ripple_to_dev (ripple_db):
+    """Convert passband ripple spec expressed in dB to an absolute value"""
+    return (10**(ripple_db/20)-1)/(10**(ripple_db/20)+1)
+
 # ----------------------------------------------------------------
 
 def remezord (fcuts, mags, devs, fsamp = 2):
@@ -210,16 +240,3 @@ def bporder (freq1, freq2, delta_p, delta_s):
     n = cinf / df + ginf * df + 1
     return n
 
-# ----------------------------------------------------------------
-#
-# def lowpass (sampling_rate, freq1, freq2,
-#              passband_ripple_db, stopband_atten_db):
-#     passband_deviation = 20 * math.log10 (1 + passband_ripple_db)
-#     stopband_deviation = -20 * math.log10 (stopband_atten_db)
-#     order = lporder (freq1/sampling_rate, freq2/sampling_rate,
-#                      passband_deviation, stopband_deviation)
-# 
-#     (n, fo, ao, w) = remezord ([freq1, freq2],
-#                                [passband_deviation, stopband_deviation],
-# 
-
